@@ -1,22 +1,8 @@
 /*
- * Copyright 2015 Thomas Lübking <thomas.luebking@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2015 Thomas Lübking <thomas.luebking@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #if (!defined ATOMS_H) || (defined ENUM_CREATE_CHAR_ARRAY)
 
@@ -157,6 +143,9 @@ ENUM_BEGIN(KwsAtom)
     ENUM(_KDE_NET_WM_WINDOW_TYPE_CRITICAL_NOTIFICATION),
     ENUM(_KDE_NET_WM_TEMPORARY_RULES),
     ENUM(_NET_WM_FRAME_OVERLAP),
+    ENUM(_KDE_NET_WM_APPMENU_SERVICE_NAME),
+    ENUM(_KDE_NET_WM_APPMENU_OBJECT_PATH),
+
     // deprecated and naming convention violation
     ENUM(_NET_WM_STATE_STAYS_ON_TOP),
 
